@@ -23,12 +23,14 @@ CHART = read_asset("templates", "features", "chart.html")
 CONFIG_PROFILE = json.loads(read_asset("profiles", "config.json"))
 FEATURES = [
     "header",
+    "pages",
     "navigation",
     "scroll",
     "status",
     "about",
     "reference",
     "time",
+    "pointer",
     "table",
     "chart",
     "markup",
